@@ -24,45 +24,91 @@
 
 #include "ad-blocker.h"
 
-#include <nsEmbedString.h>
-#include <nsIURI.h>
+#include "EphyUtils.h"
 
-AdBlocker *MozAdBlocker::mBlocker = NULL;
+#include <epiphany/ephy-embed.h>
+
+#include <nsCOMPtr.h>
+#define MOZILLA_STRICT_API
+#include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
+#include <nsIDOMAbstractView.h>
+#include <nsIDOMDocument.h>
+#include <nsIDOMDocumentView.h>
+#include <nsIDOMNode.h>
+#include <nsIDOMWindow.h>
+#include <nsIURI.h>
 
 NS_IMPL_ISUPPORTS1(MozAdBlocker, nsIContentPolicy)
 
-MozAdBlocker::MozAdBlocker()
+static EphyEmbed *
+get_embed_from_context (nsISupports *aContext)
 {
-}
+	GtkWidget *ret;
 
-void
-MozAdBlocker::SetAdBlocker (AdBlocker* blocker)
-{
-	if (mBlocker)
+	/*
+	 * aContext is either an nsIDOMWindow, an nsIDOMNode, or NULL. If it's
+	 * an nsIDOMNode, we need the nsIDOMWindow to get the EphyEmbed.
+	 */
+	if (aContext == NULL) return NULL;
+
+	nsCOMPtr<nsIDOMWindow> window;
+
+	nsCOMPtr<nsIDOMNode> node (do_QueryInterface (aContext));
+	if (node != NULL)
 	{
-		g_object_unref (mBlocker);
+		nsCOMPtr<nsIDOMDocument> domDocument;
+
+		node->GetOwnerDocument (getter_AddRefs (domDocument));
+		if (domDocument == NULL) return NULL; /* resource://... */
+
+		nsCOMPtr<nsIDOMDocumentView> docView = 
+			do_QueryInterface (domDocument);
+		g_return_val_if_fail (docView != NULL, NULL);
+
+		nsCOMPtr<nsIDOMAbstractView> view;
+		
+		docView->GetDefaultView (getter_AddRefs (view));
+		g_return_val_if_fail (view != NULL, NULL);
+
+		window = do_QueryInterface (view);
 	}
-	mBlocker = blocker;
-	if (mBlocker)
+	else
 	{
-		g_object_ref (mBlocker);
+		window = do_QueryInterface (aContext);
 	}
+	g_return_val_if_fail (window != NULL, NULL);
+
+	ret = EphyUtils::FindEmbed (window);
+	g_return_val_if_fail (EPHY_IS_EMBED (ret), NULL);
+
+	return EPHY_EMBED (ret);
 }
 
 nsresult MozAdBlocker::ShouldLoadURI(nsIURI *uri,
+				     nsISupports *aContext,
+				     PRUint32 aContentType,
 				     PRBool *_retval)
 {
+	EphyEmbed *embed;
+	AdBlocker *blocker;
+	AdUriCheckType content_type = (AdUriCheckType) aContentType;
+
 	*_retval = PR_TRUE;
 
-	if (mBlocker)
-	{
-		nsEmbedCString s;
-		uri->GetSpec(s);
+	embed = get_embed_from_context (aContext);
+	if (embed == NULL) return NS_OK;
 
-		if (ad_blocker_test_uri (mBlocker, s.get()) == FALSE)
-		{
-			*_retval = PR_FALSE;
-		}
+	blocker = AD_BLOCKER
+		(g_object_get_data (G_OBJECT (embed), AD_BLOCKER_KEY));
+	g_return_val_if_fail (blocker != NULL, NS_OK);
+
+	nsEmbedCString s;
+	uri->GetSpec(s);
+
+	if (ad_blocker_test_uri (blocker, s.get(), content_type) == TRUE)
+	{
+		*_retval = PR_FALSE;
 	}
 
 	return NS_OK;
@@ -78,9 +124,11 @@ MozAdBlocker::ShouldLoad(PRUint32 aContentType,
 			 nsISupports *aExtra,
 			 PRInt16 *aDecision)
 {
+	NS_ENSURE_ARG (aContentLocation);
+
 	PRBool accept;
 
-	ShouldLoadURI(aContentLocation, &accept);
+	ShouldLoadURI(aContentLocation, aContext, aContentType, &accept);
 
 	if (accept)
 	{
@@ -116,7 +164,9 @@ NS_IMETHODIMP MozAdBlocker::ShouldLoad(PRInt32 contentType,
 				       nsIDOMWindow *window,
 				       PRBool *_retval)
 {
-	return ShouldLoadURI(contentLocation, _retval);
+	NS_ENSURE_ARG (aContentLocation);
+
+	return ShouldLoadURI(contentLocation, ctxt, _retval);
 }
 
 /* boolean shouldProcess (in PRInt32 contentType, in nsIURI documentLocation, in nsISupports ctxt, in nsIDOMWindow window); */
