@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.1 2004/10/28 00:27:16 chpe Exp $
+ *  $Id: extension.c,v 1.2 2005/01/13 16:15:46 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-bookmarks-tray-extension.h"
 #include "ephy-debug.h"
