@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.3 2004/09/26 16:07:58 chpe Exp $
+ *  $Id: extension.c,v 1.5 2005/01/13 16:15:46 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-certificates-extension.h"
 #include "ephy-debug.h"
@@ -38,7 +36,7 @@ register_module (GTypeModule *module)
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
-        bindtextdomain (GETTEXT_PACKAGE, EPHY_PLUGINS_LOCALEDIR);
+        bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
 #endif /* ENABLE_NLS */
 
