@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.5 2004/09/26 16:07:58 chpe Exp $
+ *  $Id: extension.c,v 1.6 2005/01/13 16:15:47 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-error-viewer-extension.h"
 #include "error-viewer.h"
