@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sgml-validator.c,v 1.17 2004/10/11 17:27:53 chpe Exp $
+ *  $Id: sgml-validator.c,v 1.21 2005/01/20 15:40:40 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "sgml-validator.h"
 
@@ -237,7 +235,7 @@ check_doctype (SgmlValidator *validator,
 
 			g_free (t);
 
-			*num_errors++;
+			(*num_errors)++;
 		}
 		else
 		{
@@ -328,7 +326,7 @@ save_source_completed_cb (EphyEmbedPersist *persist,
 {
 	const char *dest;
 	char *location;
-	char *dest_utf8;
+	char *dest_utf8 = NULL;
 	gboolean is_xml;
 	unsigned int num_errors = 0;
 	OpenSPThreadCBData *data;
