@@ -19,12 +19,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-select-stylesheet-extension.c,v 1.1.2.1 2004/09/13 13:08:46 chpe Exp $
+ *  $Id: ephy-select-stylesheet-extension.c,v 1.3 2005/01/13 16:15:49 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-select-stylesheet-extension.h"
 #include "ephy-css-menu.h"
