@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.2 2004/09/26 16:07:59 chpe Exp $
+ *  $Id: extension.c,v 1.3 2005/01/13 16:15:49 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-select-stylesheet-extension.h"
 #include "ephy-css-menu.h"
