@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sidebar-extension.c,v 1.4 2005/01/01 21:33:14 crispin Exp $
+ *  $Id: ephy-sidebar-extension.c,v 1.5 2005/01/13 16:15:49 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-sidebar-extension.h"
 #include "ephy-sidebar-embed.h"
