@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-grouper.c,v 1.4 2004/11/27 23:45:30 chpe Exp $
+ *  $Id: ephy-tab-grouper.c,v 1.5 2005/01/13 16:15:50 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-tab-grouper.h"
 #include "ephy-debug.h"
