@@ -17,12 +17,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-groups-extension.c,v 1.1.2.1 2004/09/26 16:22:40 chpe Exp $
+ *  $Id: ephy-tab-groups-extension.c,v 1.3 2005/01/13 16:15:50 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-tab-groups-extension.h"
 #include "ephy-tab-grouper.h"
