@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyUtils.h,v 1.2 2004/11/20 23:18:37 chpe Exp $
+ *  $Id: EphyUtils.h,v 1.3 2004/12/06 19:04:30 chpe Exp $
  */
 
 #ifndef EPHY_UTILS_H
@@ -33,9 +33,15 @@ namespace EphyUtils
 {
 	nsresult	GetIOService		(nsIIOService **ioService);
 
-	nsresult	NewURI			(nsIURI **result, const nsAString &spec);
+	nsresult	NewURI			(nsIURI **result,
+						 const nsAString &spec,
+						 const char *charset = nsnull,
+						 nsIURI *baseURI = nsnull);
 
-	nsresult	NewURI			(nsIURI **result, const nsACString &spec);
+	nsresult	NewURI			(nsIURI **result,
+						 const nsACString &spec,
+						 const char *charset = nsnull,
+						 nsIURI *baseURI = nsnull);
 
 	GtkWidget      *FindEmbed		(nsIDOMWindow *aDOMWindow);
 
